Learn R Programming

PLPE (version 1.32.0)

lpe.paired.default: Local Pooled Error Test for Paired Data

Description

This invetigates differential expression for paired high-throughput data.

Usage

"lpe.paired"(x, design, data.type, q=0.01, probe.ID = NULL, estimator="median", w=0.5, w.estimator="fixed", iseed=1234, ...)

Arguments

x
data matrix
design
design matrix; condition index in the first column and pair index in the sceond column
q
quantile for intervals of intensities
probe.ID
probe set IDs; if NULL, row numbers are assigned.
data.type
data type: 'ms' for mass spectrometry data, 'cdna' for cDNA microarray data
estimator
specification for the estimator: 'median', 'mean' and 'huber'
w
weight paramter between individual variance estimate and pooling variance estimate, 0
w.estimator
two approaches to estimate the weight: 'random' or 'fixed'
iseed
seed number
...
other arguments

Value

design
design matrix; condition index in the first column and pair index in the sceond column
data.type
data type: 'ms' for mass spectrometry data, 'cdna' for cDNA microarray data
q
quantile for intervals of intensities
estimator
specification for the estimator: 'median', 'mean' and 'huber'
w.estimator
two approaches to estimate the weight: 'random' or 'fixed'
w
weight paramter between individual variance estimate and pooling variance estimate, 0<= w="" <="1
test.out
matrix for test results

References

Cho H, Smalley DM, Ross MM, Theodorescu D, Ley K and Lee JK (2007). Statistical Identification of Differentially Labelled Peptides from Liquid Chromatography Tandem Mass Spectrometry, Proteomics, 7:3681-3692.

See Also

lpe.paired

Examples

Run this code

#LC-MS/MS proteomic data for platelets MPs
library(PLPE)
data(plateletSet)
x <- exprs(plateletSet)
x <- log2(x) 

cond <- c(1, 2, 1, 2, 1, 2)
pair <- c(1, 1, 2, 2, 3, 3)
design <- cbind(cond, pair)

out <- lpe.paired(x, design, q=0.1, data.type="ms")
out$test.out[1:10,]
summary(out)

Run the code above in your browser using DataLab